@@ -32,10 +32,7 @@ int     ghost_pno = 0;				 /* is this a ghostbust *
 
 						  * 
 						  * * restart? */
-int     keepInfo = 15;				 /* how many updates to keep
-
-						  * 
-						  * * * infowins 6/1/93 LAB */
+int     keepInfo = 15; /* how many updates to keep infowins 6/1/93 LAB */
 int     showPlanetOwner = 0;
 
 int     phaserShrink = 0;
@@ -712,3 +709,4 @@ int F_sp_rank = 0;
 int F_sp_ltd = 0;
 int F_tips = 1;
 char *program = NULL;
+int small_screen = 0;
