@@ -35,7 +35,7 @@ void dmessage(char *message, unsigned char flags, unsigned char from, unsigned c
   register int len;
   W_Color color;
   char    timebuf[10];
-  LONG    curtime;
+  time_t  curtime;
   struct tm *tm;
   int     take, destroy, team, kill, killp, killa, bomb, conq;
   struct distress dist;
