@@ -48,16 +48,16 @@ void showdocs(int atline)
   if (!W_IsMapped(docwin))
     W_MapWindow(docwin);
 
-  sprintf(buf, "---  %s  ---", (char *) query_cowid());
+  snprintf(buf, sizeof(buf), "---  %s  ---", (char *) query_cowid());
   length = strlen(buf);
 
-  /* using GWINSIDE instead of TWINSIDE because with SMALL_SCREEN defined it
+  /* using GWINSIDE instead of TWINSIDE because with small_screen set it
    * makes more sense to use the smaller width in the interest of saving
    * screen real estate */
   center = GWINSIDE / 2 - (length * W_Textwidth) / 2;
   W_WriteText(docwin, center, W_Textheight, textColor,
 	      buf, length, W_BoldFont);
-  sprintf(buf, cbugs);
+  snprintf(buf, sizeof(buf), "%s", cbugs);
   length = strlen(buf);
   center = GWINSIDE / 2 - (length * W_Textwidth) / 2;
   W_WriteText(docwin, center, 3 * W_Textheight, textColor,
@@ -140,7 +140,7 @@ void loaddocs(void)
 
   if (temp == NULL)
     { /* malloc error checking -- 10/30/92 EM */
-      printf(malloc_fail);
+      printf("%s", malloc_fail);
       return;
     }
 
@@ -183,7 +183,7 @@ void loaddocs(void)
 
       if (temp->next == NULL)
 	{ /* malloc error checking -- 10/30/92 EM */
-	  printf(malloc_fail);
+	  printf("%s", malloc_fail);
 	  return;
 	}
 
@@ -215,12 +215,12 @@ void showxtrekrc(int atline)
   if (!W_IsMapped(xtrekrcwin))
     W_MapWindow(xtrekrcwin);
 
-  sprintf(buf, "---  %s  ---", (char *) query_cowid());
+  snprintf(buf, sizeof(buf), "---  %s  ---", (char *) query_cowid());
   length = strlen(buf);
   center = GWINSIDE / 2 - (length * W_Textwidth) / 2;
   W_WriteText(xtrekrcwin, center, W_Textheight, textColor,
 	      buf, length, W_BoldFont);
-  sprintf(buf, cbugs);
+  snprintf(buf, sizeof(buf), "%s", cbugs);
   length = strlen(buf);
   center = GWINSIDE / 2 - (length * W_Textwidth) / 2;
   W_WriteText(xtrekrcwin, center, 3 * W_Textheight, textColor,
@@ -306,7 +306,7 @@ void loadxtrekrc(void)
 
   if (temp == NULL)
     { /* malloc error checking -- 10/30/92 EM */
-      printf(malloc_fail);
+      printf("%s", malloc_fail);
       return;
     }
 
@@ -337,7 +337,7 @@ void loadxtrekrc(void)
 
       if (temp->next == NULL)
 	{ /* malloc error checking -- 10/30/92 EM */
-	  printf(malloc_fail);
+	  printf("%s", malloc_fail);
 	  return;
 	}
 
