@@ -465,7 +465,7 @@ static void gu_update()
 
   /* add words for some of the gameup flags */
   strcpy(gu_text, " ");
-  if (!context->gameup & GU_UNSAFE) {
+  if (!(context->gameup & GU_UNSAFE)) {
     strcat(gu_text, "SAFE-IDLE ");
     eager++;
   }
