@@ -4,6 +4,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <ctype.h>
+
 #include "Wlib.h"
 #include "defs.h"
 #include "struct.h"
@@ -14,6 +15,13 @@
 
 #include "option.h"
 #include "rotate.h"
+#include "docwin.h"
+#include "udpopt.h"
+#include "netstatopt.h"
+#include "pingstats.h"
+#include "spopt.h"
+#include "defwin.h"
+#include "socket.h"
 
 int     notdone;				 /* not done flag */
 
@@ -333,7 +341,6 @@ struct option Visual_Menu[] =
   {-1, NULL, 0, 0, 0, 0, NULL, NULL}
 };
 
-#ifdef HAVE_XPM
 struct option Pixmap_Menu[] =
 {
   {0, "Pixmap Menu", &MenuPage, 0, 0, 0, NULL, &Menus_Range},
@@ -353,9 +360,6 @@ struct option Pixmap_Menu[] =
   {-1, NULL, 0, 0, 0, 0, NULL, NULL}
 };
 
-#endif
-
-
 #define NUMOPTIONS(menu) ((sizeof((menu))/sizeof((menu)[0]))-1)
 
 /* option menu sizes and such */
@@ -496,12 +500,9 @@ static void optionrefresh(register struct option *op)
       /* Either a boolean or a window */
       if (op->op_option)
 
-#ifdef HAVE_XPM
 	if (op->op_size)			 /* Pixmap Bit Value */
 	  on = !(*op->op_option & op->op_size);
 	else
-#endif
-
 	  on = *op->op_option;			 /* use int for status */
       else if (op->op_targetwin)
 	on = W_IsMapped(*op->op_targetwin);	 /* use window for status */
@@ -731,12 +732,36 @@ void    optionaction(W_Event * data)
 	*(op->op_option) = op->op_range->min_value;
       if (*(op->op_option) < op->op_range->min_value)
 	*(op->op_option) = op->op_range->max_value;
+      if (op->op_option == &client_ups)
+	{
+	  switch (data->key) {
+	  case W_LBUTTON:
+	    switch (*op->op_option) {
+	    case 9: *op->op_option = 5; break;
+	    case 24: *op->op_option = 10; break;
+	    case 49: *op->op_option = 25; break;
+	    }
+	    break;
+	  case W_MBUTTON:
+	    *op->op_option = 5;
+	    break;
+	  case W_RBUTTON:
+	    switch (*op->op_option) {
+	    case 6: *op->op_option = 10; break;
+	    case 11: *op->op_option = 25; break;
+	    case 26: *op->op_option = 50; break;
+	    }
+	    break;
+	  }
+	  if (client_ups != server_ups) {
+	    sendUpdatePacket(1000000 / client_ups);
+	  }
+	}
     }
 
 
   /* Is the option a toggle? */
 
-#ifdef HAVE_XPM
   /* Bitwise Toggle  */
 
   else if ((op->op_option) && (op->op_size))
@@ -749,8 +774,6 @@ void    optionaction(W_Event * data)
 	    redrawall = 1;
 	}
     }
-#endif
-
   else if (op->op_option)
     {
       *op->op_option = !*op->op_option;
@@ -856,10 +879,6 @@ void optiondone(void)
     }
   *newkeys = '\0';
 
-  if (client_ups != server_ups) {
-    sendUpdatePacket(1000000 / client_ups);
-  }
-
   sendOptionsPacket(); /* update server as to the client's options */
 }
 
@@ -876,11 +895,7 @@ static int InitOptionMenus(void)
   AddOptMenu(Planet_Menu, 0);
   AddOptMenu(Visual_Menu, 0);
   AddOptMenu(Window_Menu, 0);
-
-#ifdef HAVE_XPM
   AddOptMenu(Pixmap_Menu, 0);
-#endif
-
 
   for (i = 0, CurrentMenu = FirstMenu; CurrentMenu != NULL;
        i++, CurrentMenu = CurrentMenu->Next)
