@@ -9,14 +9,7 @@
 
 /* Function Definitions */
 
-void parsemeta(int metaType);
-/*
- * Read and Parse the metaserver information, either from the metaservers
- * by UDP (1), from a single metaserver by TCP (3), or from the cache (2).
- *  
- * NOTE: This function sets the variable "num_servers" which is
- * used in newwin() to set the height of the meta-server window.
- */
+void parsemeta();
 
 void metawindow(void);
 /*
