@@ -7,6 +7,7 @@
 #include <stdio.h>
 #include <stdlib.h>
 #include <netdb.h>
+#include <netinet/in.h>
 
 #include "Wlib.h"
 #include "defs.h"
@@ -916,7 +917,7 @@ void    handleSMessage(struct mesg_s_spacket *packet)
   char    addrbuf[9];
 
   if (debug)
-    printf("Length of Message is: %d  total Size %d \n", strlen(&packet->mesg), (int) packet->length);
+    printf("Length of Message is: %zd  total Size %d \n", strlen(&packet->mesg), (int) packet->length);
   if (packet->m_from >= MAXPLAYER)
     packet->m_from = 255;
 
@@ -1734,7 +1735,7 @@ void    handleSWarning(struct warning_s_spacket *packet)
     case DGHOSTKILL:
       {
 	struct mesg_spacket msg;
-	ushort  damage;
+	unsigned short damage;
 
 	damage = (unsigned char) karg3;
 	damage |= (unsigned char) (karg4 & 0xff) << 8;
@@ -1979,7 +1980,7 @@ unsigned char *sbuf;
   struct phaser_s_spacket *packet = (struct phaser_s_spacket *) &sbuf[0];
 
   /* not nice but.. */
-  register int pnum, status, target, x, y, dir;
+  register int pnum, status, target = 0, x = 0, y = 0, dir = 0;
 
   status = packet->status & 0x0f;
   pnum = packet->pnum & 0x3f;
